@@ -3,5 +3,7 @@ import axon.comms_wrappers
 import axon.config
 import axon.discovery
 import axon.return_value_linker
+import axon.simplex_stubs
+import axon.duplex_stubs
 import axon.utils
 import axon.worker
\ No newline at end of file
